@@ -50,7 +50,7 @@ from domdf_python_tools.typing import PathLike
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020-2021 Dominic Davis-Foster"
 __license__: str = "MIT License"
-__version__: str = "0.3.1"
+__version__: str = "0.3.2"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["Visitor", "Plugin"]
@@ -235,8 +235,12 @@ class Visitor(flake8_helper.Visitor):
 				return self.generic_visit(node)
 
 			else:
-				inferred_types = get_inferred_types(self.jedi_script, node)
-				method_name = tuple(get_attribute_name(node.func))[-1]
+
+				try:
+					inferred_types = get_inferred_types(self.jedi_script, node)
+					method_name = tuple(get_attribute_name(node.func))[-1]
+				except NotImplementedError:  # pragma: no cover
+					return self.generic_visit(node)
 
 				for class_name in inferred_types:
 					if is_configparser_read(class_name, method_name):
